
# Type: subclass of


holds between two classes where the domain class is a specialization of the range class

URI: [biolink:subclass_of](https://w3id.org/biolink/vocab/subclass_of)


## Domain and Range

[OntologyClass](OntologyClass.md) ->  <sub>0..*</sub> [IriType](types/IriType.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [Attribute](Attribute.md)
 * [BiologicalSex](BiologicalSex.md)
 * [ClinicalModifier](ClinicalModifier.md)
 * [FrequencyValue](FrequencyValue.md)
 * [GeneOntologyClass](GeneOntologyClass.md)
 * [GenotypicSex](GenotypicSex.md)
 * [Onset](Onset.md)
 * [OntologyClass](OntologyClass.md)
 * [OrganismTaxon](OrganismTaxon.md)
 * [PhenotypicSex](PhenotypicSex.md)
 * [RelationshipType](RelationshipType.md)
 * [SeverityValue](SeverityValue.md)
 * [Zygosity](Zygosity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | rdfs:subClassOf |
|  | | SEMMEDDB:IS_A |
|  | | WD:P279 |
| **In Subsets:** | | translator_minimal |

